@@ -1,4 +1,4 @@
-#' @title Crate a Spatiotemporal Classification Task
+#' @title Create a Spatiotemporal Classification Task
 #'
 #' @description This task specializes [Task] and [TaskSupervised] for
 #' spatiotemporal classification problems. The target column is assumed to be a
@@ -26,8 +26,10 @@
 #' @export
 #' @examples
 #' if (mlr3misc::require_namespaces(c("sf", "blockCV"), quietly = TRUE)) {
-#'   task = as_task_classif_st(ecuador, target = "slides",
-#'     positive = "TRUE", coordinate_names = c("x", "y"))
+#'   task = as_task_classif_st(ecuador,
+#'     target = "slides",
+#'     positive = "TRUE", coordinate_names = c("x", "y")
+#'   )
 #'
 #'   # passing objects of class 'sf' is also supported
 #'   data_sf = sf::st_as_sf(ecuador, coords = c("x", "y"))
@@ -50,25 +52,32 @@ TaskClassifST = R6::R6Class("TaskClassifST",
     initialize = function(id, backend, target, positive = NULL,
       label = NA_character_, coordinate_names, crs = NA_character_,
       coords_as_features = FALSE, extra_args = list()) {
+      if (inherits(backend, "sf")) {
+        stopf("Creating tasks from `sf` objects is not supported anymore since >= v2.0.0. Use `as_task_classif_st()` to convert sf objects into a task.") # nolint
+      }
 
-      super$initialize(id = id, backend = backend, target = target,
-        positive = positive, extra_args = extra_args)
+      super$initialize(
+        id = id, backend = backend, target = target,
+        positive = positive, extra_args = extra_args
+      )
 
       self$crs = crs
       self$coordinate_names = coordinate_names
       walk(coordinate_names, function(x) {
         assert_numeric(self$backend$head(1)[[x]], .var.name = x)
       })
-      self$coords_as_features = assert_flag(coords_as_features)
+
+      if (packageVersion("mlr3") > "0.13.4") {
+        # adjust classif task
+        self$task_type = "classif_st"
+        new_col_roles = named_list(setdiff(
+          mlr_reflections$task_col_roles[["classif_st"]],
+          names(private$.col_roles)), character(0))
+        private$.col_roles = insert_named(private$.col_roles, new_col_roles)
+      }
 
       # add coordinates as features
       self$coords_as_features = assert_flag(coords_as_features)
-
-      new_col_roles = named_list(
-        setdiff(mlr_reflections$task_col_roles[["classif_st"]],
-          names(private$.col_roles)), character(0)
-      )
-      private$.col_roles = insert_named(private$.col_roles, new_col_roles)
     },
 
     #' @description
@@ -97,11 +106,15 @@ TaskClassifST = R6::R6Class("TaskClassifST",
           sprintf("  - Space: %s", self$col_roles$space)
         ))
       } else if (length(self$col_roles$time)) {
-        catn(c("* Column roles:",
-          sprintf("  - Time: %s", self$col_roles$time)))
+        catn(c(
+          "* Column roles:",
+          sprintf("  - Time: %s", self$col_roles$time)
+        ))
       } else if (length(self$col_roles$space)) {
-        catn(c("* Column roles:",
-          sprintf("  - Space: %s", self$col_roles$space)))
+        catn(c(
+          "* Column roles:",
+          sprintf("  - Space: %s", self$col_roles$space)
+        ))
       }
     }
   ),
@@ -122,12 +135,17 @@ TaskClassifST = R6::R6Class("TaskClassifST",
       if (missing(rhs)) {
         return(self$extra_args$coordinate_names)
       }
-      self$extra_args$coordinate_names = assert_character(rhs, len = 2,
-        all.missing = FALSE, any.missing = FALSE)
+      self$extra_args$coordinate_names = assert_character(rhs,
+        len = 2,
+        all.missing = FALSE, any.missing = FALSE
+      )
     },
 
     #' @field coords_as_features (`logical(1)`)\cr
-    #'   If `TRUE`, coordinates are used as features.
+    #'  If `TRUE`, coordinates are used as features.
+    #'  This is a shortcut for
+    #'  `task$set_col_roles(c("x", "y"), role = "feature")` with the assumption
+    #'  that the coordinates in the data are named `"x"` and `"y"`.
     coords_as_features = function(rhs) {
       if (missing(rhs)) {
         return(self$extra_args$coords_as_features)
