@@ -31,8 +31,7 @@ load_task_diplodia = function(id = "diplodia") {
   task = TaskClassifST$new(
     id = "diplodia", b,
     target = "diplo01", positive = "1",
-    extra_args = list(
-      coordinate_names = c("x", "y"), coords_as_features = FALSE,
-      crs = "+proj=utm +zone=30 +south +datum=WGS84 +units=m +no_defs"))
+    coordinate_names = c("x", "y"), coords_as_features = FALSE,
+    crs = "+proj=utm +zone=30 +south +datum=WGS84 +units=m +no_defs")
   return(task)
 }
