@@ -15,7 +15,8 @@ test_that("printing works", {
 test_that("Supplying a non-spatio temporal task gives descriptive error message", {
   expect_error(
     rsmp("spcv_coords")$instantiate(tsk("boston_housing")),
-    "Must inherit from class 'TaskClassifST' or 'TaskRegrST'.") # nolint
+    "Must inherit from class 'TaskClassifST' or 'TaskRegrST'."
+  ) # nolint
 })
 
 test_that("coordinates can be used as features", {
@@ -68,7 +69,30 @@ test_that("extra_args contains default arguments", {
     coordinate_names = c("x", "y")
   )
 
-  expect_equal(task$extra_args, list(crs = NA_character_,
+  expect_equal(task$extra_args, list(
+    crs = NA_character_,
     coordinate_names = c("x", "y"), coords_as_features = FALSE
   ))
 })
+
+test_that("Task creation works via constructor and sf object", {
+  data_sf = sf::st_as_sf(ecuador, coords = c("x", "y"))
+
+  # create mlr3 task
+  expect_error(TaskClassifST$new("ecuador_sf",
+    backend = data_sf, target = "slides", positive = "TRUE"))
+})
+
+test_that("Task creation works via constructor and sf object", {
+  data = test_make_sp()
+  data$p_1 = c(rep("A", 18), rep("B", 18))
+  data$response = rnorm(36)
+
+  data_sf = sf::st_as_sf(data, coords = c("x", "y"))
+
+  # create mlr3 task via constructor
+  expect_error(TaskClassifST$new("ecuador_sf",
+    backend = data_sf,
+    target = "response"
+  ), "Creating tasks from `sf` objects is not supported anymore")
+})
