@@ -1,5 +1,5 @@
 test_that("spcv methods work in a Graph Learner", {
-
+  skip("until mlr3filters >= 0.5.1 in on CRAN - including as_task assertion fix")
   skip_if_not_installed("mlr3pipelines")
   skip_if_not_installed("blockCV")
 
@@ -20,7 +20,6 @@ test_that("spcv methods work in a Graph Learner", {
 })
 
 test_that("sptcv methods work in a Graph Learner", {
-
   skip_if_not_installed("mlr3pipelines")
 
   skip_on_cran()
@@ -32,7 +31,8 @@ test_that("sptcv methods work in a Graph Learner", {
     test_graph_learner(task_cluto, x,
       time_var = "Date",
       learner = "regr.featureless",
-      measure = "regr.mse")
+      measure = "regr.mse"
+    )
   })
 
   expect_true(all(out))
